Struct libipld_json::Error [−][src]
pub struct Error { /* fields omitted */ }Expand description
This type represents all possible errors that can occur when serializing or deserializing JSON data.
Implementations
impl Error[src]
impl Error[src]pub fn line(&self) -> usize[src]
pub fn line(&self) -> usize[src]One-based line number at which the error was detected.
Characters in the first line of the input (before the first newline character) are in line 1.
pub fn column(&self) -> usize[src]
pub fn column(&self) -> usize[src]One-based column number at which the error was detected.
The first character in the input and any characters immediately following a newline character are in column 1.
Note that errors may occur in column 0, for example if a read from an IO stream fails immediately following a previously read newline character.
pub fn classify(&self) -> Category[src]
pub fn classify(&self) -> Category[src]Categorizes the cause of this error.
Category::Io- failure to read or write bytes on an IO streamCategory::Syntax- input that is not syntactically valid JSONCategory::Data- input data that is semantically incorrectCategory::Eof- unexpected end of the input data
pub fn is_io(&self) -> bool[src]
pub fn is_io(&self) -> bool[src]Returns true if this error was caused by a failure to read or write bytes on an IO stream.
pub fn is_syntax(&self) -> bool[src]
pub fn is_syntax(&self) -> bool[src]Returns true if this error was caused by input that was not syntactically valid JSON.